==> checkotp-0.0.7.tar.gz: lib/checkotp.dart <==
library checkotp;

import 'dart:convert';
import 'package:crypto/crypto.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';

/// CheckOTP
class CheckOTP {
  Future<String> matchToken(String value, String token) async {
    var digest = md5.convert(utf8.encode(value)).toString();
    print("digest: " + digest);

    SharedPreferences prefs = await SharedPreferences.getInstance();
    var token = prefs.getString('dt_ihoe515253');

    if (digest == token) {
      return "match";
    } else {
      return "mismatch";
    }
  }

  Future<String> makeOTPRequest(
      String mobile, String appkey, String passphrase) async {
    var toLaunch = 'http://droptxt.app/api/otp/v1/?appkey=' +
        appkey +
        '&passphrase=' +
        passphrase +
        '&mobile=' +
        mobile;

    var res = await http
        .get(Uri.parse(toLaunch), headers: {"Accept": "application/json"});
    var otpResponse = res.body.toString();
    print(otpResponse);

    //get the values to know what to do
    //OTPSent is success
    //OTPFailed is for something went wrong
    //The initial response from the server will be printed on console for debugging to decide action points
    Map<String, dynamic> response = jsonDecode(otpResponse);
    var status = response['status'];
    if (status == 'OTPSent') {
      //let's get the token value
      var token = response['token'];
      //let's push it to shared preferences
      SharedPreferences prefs = await SharedPreferences.getInstance();
      await prefs.setString('dt_ihoe515253', token);
    }
    return status;
  }
}

==> checkotp-0.0.9.tar.gz: lib/checkotp.dart <==
library checkotp;

import 'dart:convert';
import 'package:crypto/crypto.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';

/// CheckOTP
class CheckOTP {
  Future<String> matchToken(String value) async {
    var digest = md5.convert(utf8.encode(value)).toString();
    print("digest: " + digest);

    SharedPreferences prefs = await SharedPreferences.getInstance();
    var token = prefs.getString('dt_ihoe515253');

    if (digest == token) {
      return "match";
    } else {
      return "mismatch";
    }
  }

  Future<String> makeOTPRequest(
      String mobile, String appkey, String passphrase) async {
    var toLaunch = 'http://droptxt.app/api/otp/v1/?appkey=' +
        appkey +
        '&passphrase=' +
        passphrase +
        '&mobile=' +
        mobile;

    var res = await http
        .get(Uri.parse(toLaunch), headers: {"Accept": "application/json"});
    var otpResponse = res.body.toString();
    print(otpResponse);

    //get the values to know what to do
    //OTPSent is success
    //OTPFailed is for something went wrong
    //The initial response from the server will be printed on console for debugging to decide action points
    Map<String, dynamic> response = jsonDecode(otpResponse);
    var status = response['status'];
    if (status == 'OTPSent') {
      //let's get the token value
      var token = response['token'];
      //let's push it to shared preferences
      SharedPreferences prefs = await SharedPreferences.getInstance();
      await prefs.setString('dt_ihoe515253', token);
    }
    return status;
  }
}
